Index: utils.c
===================================================================
--- utils.c	(revision 8433)
+++ utils.c	(working copy)
@@ -43,6 +43,7 @@
 #include "asterisk/io.h"
 #include "asterisk/logger.h"
 #include "asterisk/md5.h"
+#include "asterisk/sha1.h"
 #include "asterisk/options.h"
 #include "asterisk/compat.h"
 
@@ -297,6 +298,25 @@
 		ptr += sprintf(ptr, "%2.2x", digest[x]);
 }
 
+
+void ast_sha1_hash(char *output, char *input)
+{
+	struct SHA1Context sha;
+	unsigned char digest[16];
+	char *ptr;
+	int x;
+	uint8_t Message_Digest[20];
+
+	SHA1Reset(&sha);
+	
+	SHA1Input(&sha, (const unsigned char *) input, strlen(input));
+
+	SHA1Result(&sha, Message_Digest);
+	ptr= output;
+	for (x=0; x<20; x++)
+		ptr += sprintf(ptr, "%2.2x", Message_Digest[x]);
+}
+
 int ast_base64decode(unsigned char *dst, const char *src, int max)
 {
 	int cnt = 0;
Index: channel.c
===================================================================
--- channel.c	(revision 8433)
+++ channel.c	(working copy)
@@ -72,6 +72,7 @@
 #include "asterisk/app.h"
 #include "asterisk/transcap.h"
 #include "asterisk/devicestate.h"
+#include "asterisk/sha1.h"
 
 struct channel_spy_trans {
 	int last_format;
Index: Makefile
===================================================================
--- Makefile	(revision 8433)
+++ Makefile	(working copy)
@@ -351,7 +351,7 @@
 	astmm.o enum.o srv.o dns.o aescrypt.o aestab.o aeskey.o \
 	utils.o plc.o jitterbuf.o dnsmgr.o devicestate.o \
 	netsock.o slinfactory.o ast_expr2.o ast_expr2f.o \
-	cryptostub.o
+	cryptostub.o sha1.o
 
 ifeq ($(wildcard $(CROSS_COMPILE_TARGET)/usr/include/sys/poll.h),)
   OBJS+= poll.o
Index: include/asterisk/utils.h
===================================================================
--- include/asterisk/utils.h	(revision 8433)
+++ include/asterisk/utils.h	(working copy)
@@ -145,6 +145,9 @@
 /* ast_md5_hash 
 	\brief Produces MD5 hash based on input string */
 void ast_md5_hash(char *output, char *input);
+/* ast_sha1_hash
+	\brief Produces SHA1 hash based on input string */
+void ast_sha1_hash(char *output, char *input);
 
 int ast_base64encode(char *dst, const unsigned char *src, int srclen, int max);
 int ast_base64decode(unsigned char *dst, const char *src, int max);
Index: funcs/Makefile
===================================================================
--- funcs/Makefile	(revision 8433)
+++ funcs/Makefile	(working copy)
@@ -24,8 +24,9 @@
          func_timeout.o \
          func_language.o \
          func_moh.o \
-         func_base64.o
-
+         func_base64.o \
+	func_sha1.o
+	
 AVAILABLE_FUNCS=$(filter-out $(BUILTINS),$(patsubst %.c,%.o,$(wildcard func*.c)))
 
 ifeq ($(wildcard $(CROSS_COMPILE_TARGET)/usr/include/odbcinst.h)$(wildcard $(CROSS_COMPILE_TARGET)/usr/local/include/odbcinst.h),)
